<quotes-tiny>
    <table class="quotes-table">
        <thead>
            <tr>
                <th>{window.__('Instrument', 'amarkets-partials')}</th>
                <th>{window.__('Bid', 'amarkets-partials')}</th>
                <th>{window.__('Ask', 'amarkets-partials')}</th>
                <th>{window.__('Spread', 'amarkets-partials')}</th>
            </tr>
        </thead>

        <tbody>
            <tr each={get.quotes()} data-quote="{name}">
                <td><span>{name}</span></td>

                <td class="bid digits{digits}">
                    {get.digits_except_last(bid)}<span class="last-digit">{get.last_digit(bid)}</span>
                    <i class="{get.arrow_class(db)}"></i>
                </td>

                <td class="ask digits{digits}">
                    {get.digits_except_last(ask)}<span class="last-digit">{get.last_digit(ask)}</span>
                    <i class="{get.arrow_class(da)}"></i>
                </td>

                <td>{spread}</td>
            </tr>
        </tbody>
    </table>


    <script>

        this.get = {
            digits_except_last: (number) => {
                return number.slice(0, -1);
            },

            last_digit: (number) => {
                return number.slice(-1);
            },

            quotes: () => {
                return Array.from(this.quotes_map.values());
            },

            arrow_class: (diff) => {
                if (diff === 1) {
                    return 'fas fa-sort-up';
                }

                if (diff === -1) {
                    return 'fas fa-sort-down';
                }

                return '';
            },
        };

        updateQuotesFromWs(event) {
            var quotes = JSON.parse(event.data);

            this.quotes_map.forEach(function(value, key, map) {
                value.da = 0;
                value.db = 0;
            });

            for (var i = quotes.length - 1; i >= 0; i--) {
                // Remove extra 'b' from names.
                var last_letter = quotes[i].name.substr(-1);
                if (last_letter === 'b') {
                    quotes[i].name = quotes[i].name.substr(0, quotes[i].name.length - 1);
                };

                // Force proper ask and bid decimal places.
                quotes[i].ask = quotes[i].ask.toFixed(quotes[i].digits);
                quotes[i].bid = quotes[i].bid.toFixed(quotes[i].digits);

                // Exclude following instruments.
                if (   quotes[i].name == 'USDRUB'
                    || quotes[i].name == 'EURRUB'
                    || quotes[i].name == 'RTS'
                    || quotes[i].name == 'NGAS'
                    || quotes[i].name == 'ITA40'
                    || quotes[i].name == 'COPPER'
                    || quotes[i].name == 'IBEX35'
                    || quotes[i].name == 'CAC40'
                    || quotes[i].name == 'EuroStoxx50'
                    || quotes[i].name == 'ETHUSD'
                    || quotes[i].name == 'GBPJPY'
                    || quotes[i].name == 'EURGBP'
                    || quotes[i].name == 'EURJPY'
                    ) {
                    continue;
                }
                this.quotes_map.set(quotes[i].name, quotes[i]);
            }

            this.update();
        }

        this.quotes_map = new Map();
        this.socket = new ReconnectingWebSocket("wss://ws.du3b.com/wss/quotes_tiny");
        this.socket.onmessage = this.updateQuotesFromWs;

    </script>


    <style>

        .quotes-table {
            margin-bottom: 0;
        }
        .quotes-table thead,
        .quotes-table tbody {
            border: none;
        }

        .quotes-table thead th,
        .quotes-table thead td,
        .quotes-table tbody th,
        .quotes-table tbody td {
            text-align: right;
        }

        .quotes-table thead th:first-child,
        .quotes-table thead td:first-child,
        .quotes-table tbody th:first-child,
        .quotes-table tbody td:first-child {
            text-align: left;
        }
        @media print, screen and (min-width: 48em) {
            .quotes-table thead th:first-child,
            .quotes-table thead td:first-child,
            .quotes-table tbody th:first-child,
            .quotes-table tbody td:first-child {
                width: 145px;
            }
        }

        .quotes-table thead th:last-child,
        .quotes-table thead td:last-child,
        .quotes-table tbody th:last-child,
        .quotes-table tbody td:last-child {
            text-align: center;
        }
        @media (max-width: 390px) {
            .quotes-table thead th:last-child,
            .quotes-table thead td:last-child,
            .quotes-table tbody th:last-child,
            .quotes-table tbody td:last-child {
                display: none;
            }
        }

        .quotes-table tbody td {
            color: #7c878f;
            position: relative;
        }

        .quotes-table tbody td:first-child {
            color: #252e37;
        }

        .quotes-table tbody td i {
            font-size: 16px;
            position: absolute;
            right: 2px;
            top: 50%;
        }
        @media (max-width: 374px) {
            .quotes-table tbody td i {
                font-size: 12px;
                right: 5px;
            }
        }

        .quotes-table tbody td .fa-sort-up {
            color: #4caf50;
            -webkit-transform: translateY(-35%);
            -ms-transform: translateY(-35%);
            transform: translateY(-35%);
        }
        @media print, screen and (min-width: 48em) {
            .quotes-table tbody td .fa-sort-up {
                -webkit-transform: translateY(-40%);
                -ms-transform: translateY(-40%);
                transform: translateY(-40%);
            }
        }

        .quotes-table tbody td .fa-sort-down {
            color: #ee5921;
            -webkit-transform: translateY(-75%);
            -ms-transform: translateY(-75%);
            transform: translateY(-75%);
        }
        @media print, screen and (min-width: 48em) {
            .quotes-table tbody td .fa-sort-down {
                -webkit-transform: translateY(-80%);
                -ms-transform: translateY(-80%);
                transform: translateY(-80%);
            }
        }

        .digits3 .last-digit,
        .digits5 .last-digit {
            font-size: 12px;
        }

        @media print, screen and (max-width: 440px) {
            .quotes-table th, .quotes-table td {
                padding: 0.65rem 0.825rem;
            }
        }

    </style>

</quotes-tiny>
